@@ -11,6 +11,7 @@ use Data::Dumper;
 use Params::Check               qw[check];
 use Module::Load::Conditional   qw[can_load];
 use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
+use version;
 
 $Params::Check::VERBOSE = 1;
 
@@ -332,7 +333,7 @@ sub _send_report {
     my $grade;
     ### check if this is a platform specific module ###
     ### if we failed the test, there may be reasons why 
-    ### an 'NA' might have to be insted
+    ### an 'NA' might have to be instead
     GRADE: { if ( $failed ) {
         
 
@@ -347,7 +348,22 @@ sub _send_report {
         ### as FAIL modules where prereqs are not filled
         {   my $prq = $mod->status->prereqs || {};
         
-            while( my($prq_name,$prq_ver) = each %$prq ) {
+            PREREQ: while( my($prq_name,$prq_ver) = each %$prq ) {
+
+                # 'perl' listed as prereq
+
+                if ( $prq_name eq 'perl' ) {
+                   my $req_ver = eval { version->new( $prq_ver ) };
+                   next PREREQ unless $req_ver;
+                   if ( version->new( $] ) < $req_ver ) {
+                      msg(loc("'%1' requires a higher version of perl than your current ".
+                              "version -- sending N/A grade.", $name), $verbose);
+
+                      $grade = GRADE_NA;
+                      last GRADE;
+                   }
+                }
+
                 my $obj = $cb->module_tree( $prq_name );
                 my $sub = CPANPLUS::Module->can(         
                             'module_is_supplied_with_perl_core' );
@@ -359,13 +375,13 @@ sub _send_report {
                 ### version of perl (5.8.6+ and 5.9.2-4 at the time of writing)
                 ### 'Config' is not recognized as a core module. See this bug:
                 ###    http://rt.cpan.org/Ticket/Display.html?id=32155
-                if( !$obj and !$sub->( $prq_name ) ) {
+                if( !$obj and !defined $sub->( $prq_name ) ) {
                     msg(loc( "Prerequisite '%1' for '%2' could not be obtained".
                              " from CPAN -- sending N/A grade", 
                              $prq_name, $name ), $verbose );
 
                     $grade = GRADE_NA;
-                    last GRADE;        
+                    last GRADE;
                 }
 
                 if ( !$obj ) {
@@ -377,7 +393,7 @@ sub _send_report {
                                $name, $prq_ver ), $verbose );
                              
                       $grade = GRADE_NA;
-                      last GRADE;        
+                      last GRADE;
                     }
                 }
 
@@ -388,7 +404,7 @@ sub _send_report {
                              $name, $prq_ver ), $verbose );
                              
                     $grade = GRADE_NA;
-                    last GRADE;        
+                    last GRADE;
                 }                             
             }
         }
@@ -413,8 +429,8 @@ sub _send_report {
         } elsif ( PERL_VERSION_TOO_LOW->( $buffer ) ) {
             msg(loc("'%1' requires a higher version of perl than your current ".
                     "version -- sending N/A grade.", $name), $verbose);
-        
-            $grade = GRADE_NA;                
+
+            $grade = GRADE_NA;
 
         ### perhaps where were no tests...
         ### see if the thing even had tests ###
@@ -426,7 +442,7 @@ sub _send_report {
             $grade = GRADE_UNKNOWN
 
         } else {
-            
+
             $grade = GRADE_FAIL;
         }
 
@@ -529,7 +545,7 @@ sub _send_report {
     $reporter->from( $conf->get_conf('email') )
         if $conf->get_conf('email') !~ /\@example\.\w+$/i;
 
-    ### give the user a chance to programattically alter the message
+    ### give the user a chance to programatically alter the message
     $message = $self->_callbacks->munge_test_report->($mod, $message, $grade);
 
     ### add the body if we have any ###
